==> rfc_lookup-1.0.0.tar.gz: rfc_lookup-1.0.0/README.md <==
<div align="center">

# RFC Lookup

This project is a simple command-line interface that allows for easily looking
up and searching for RFCs from the command line. It uses the resources provided by [IETF](https://www.ietf.org/) and the [RFC Editor](https://www.rfc-editor.org/) to provide the most up-to-date information on RFCs.

<br />

[![Tests](https://github.com/xransum/rfc-lookup/workflows/Tests/badge.svg)][tests]
[![Codecov](https://codecov.io/gh/xransum/rfc-lookup/branch/main/graph/badge.svg)][codecov]
[![PyPI](https://img.shields.io/pypi/v/rfc-lookup.svg)][pypi_]
[![Python Version](https://img.shields.io/pypi/pyversions/rfc-lookup)][python version]

[![Python Black](https://img.shields.io/badge/code%20style-black-000000.svg?label=Style)](https://github.com/xransum/rfc-lookup)
[![Read the documentation at https://rfc-lookup.readthedocs.io/](https://img.shields.io/readthedocs/rfc-lookup/latest.svg?label=Read%20the%20Docs)][read the docs]
[![Downloads](https://pepy.tech/badge/rfc-lookup)](https://pepy.tech/project/rfc-lookup)
[![License](https://img.shields.io/pypi/l/rfc-lookup)][license]

</div>

## Installation

To install the RFC Lookup project, run this command in your terminal:

```bash
pip install rfc-lookup
```

## Usage

RFC Lookup's usage looks like:

```bash
rfc [OPTIONS]
```

For usage instructions, please refer to the [Usage][usage] documentation.

## Reference

For a complete list of available functions and classes, please refer to the [Reference][reference] documentation.

## Contributing

Contributions are very welcome. To learn more, see the [Contributor Guide][contributing].

## License

Distributed under the terms of the [MIT license][license], _rfc-lookup_ is
free and open source software.

## Issues

If you encounter any problems, please [file an issue] along with a detailed
description.

## Credits

This project was built off of the sweat and tears of the the bad actors it was
built to fight.

<!-- github-only -->

[pypi_]: https://pypi.org/project/rfc-lookup/
[python version]: https://pypi.org/project/rfc-lookup
[read the docs]: https://rfc-lookup.readthedocs.io/
[reference]: https://rfc-lookup.readthedocs.io/en/latest/reference/
[usage]: https://rfc-lookup.readthedocs.io/en/latest/
[tests]: https://github.com/xransum/rfc-lookup/actions?workflow=Tests
[codecov]: https://app.codecov.io/gh/xransum/rfc-lookup
[contributing]: ./CONTRIBUTING.md
[license]: ./LICENSE

==> rfc_lookup-1.0.2.tar.gz: rfc_lookup-1.0.2/README.md <==
<div align="center">

# RFC Lookup

This project is a simple command-line interface that allows for easily looking
up and searching for RFCs from the command line. It uses the resources provided
by [IETF](https://www.ietf.org/) and the
[RFC Editor](https://www.rfc-editor.org/) to provide the most up-to-date
information on RFCs.

<br />

[![Tests](https://github.com/xransum/rfc-lookup/workflows/Tests/badge.svg)][tests]
[![Codecov](https://codecov.io/gh/xransum/rfc-lookup/branch/main/graph/badge.svg)][codecov]
[![PyPI](https://img.shields.io/pypi/v/rfc-lookup.svg)][pypi_]
[![Python Version](https://img.shields.io/pypi/pyversions/rfc-lookup)][python version]

[![Python Black](https://img.shields.io/badge/code%20style-black-000000.svg?label=Style)](https://github.com/xransum/rfc-lookup)
[![Read the documentation at https://rfc-lookup.readthedocs.io/](https://img.shields.io/readthedocs/rfc-lookup/latest.svg?label=Read%20the%20Docs)][read the docs]
[![Downloads](https://pepy.tech/badge/rfc-lookup)](https://pepy.tech/project/rfc-lookup)
[![License](https://img.shields.io/pypi/l/rfc-lookup)][license]

</div>

## Installation

To install the RFC Lookup project, run this command in your terminal:

```bash
pip install rfc-lookup
```

## Usage

RFC Lookup's usage looks like:

```bash
rfc [OPTIONS]
```

For usage instructions, please refer to the [Usage][usage] documentation.

## Reference

For a complete list of available functions and classes, please refer to the
[Reference][reference] documentation.

## Contributing

Contributions are very welcome. To learn more, see the [Contributor
Guide][contributing].

## License

Distributed under the terms of the [MIT license][license], _rfc-lookup_ is free
and open source software.

## Issues

If you encounter any problems, please [file an issue] along with a detailed
description.

## Credits

This project was built off of the sweat and tears of the the bad actors it was
built to fight.

<!-- github-only -->

[pypi_]: https://pypi.org/project/rfc-lookup/
[python version]: https://pypi.org/project/rfc-lookup
[read the docs]: https://rfc-lookup.readthedocs.io/
[reference]: https://rfc-lookup.readthedocs.io/en/latest/reference/
[usage]: https://rfc-lookup.readthedocs.io/en/latest/
[tests]: https://github.com/xransum/rfc-lookup/actions?workflow=Tests
[codecov]: https://app.codecov.io/gh/xransum/rfc-lookup
[contributing]: ./CONTRIBUTING.md
[license]: ./LICENSE
